@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::Schema::ResultSet::TestReport;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 # ABSTRACT: Query the raw test reports
 
 #pod =head1 SYNOPSIS
@@ -72,9 +72,12 @@ sub insert_metabase_fact( $self, $fact ) {
         }
     );
 
+    my $format = DateTime::Format::ISO8601->new();
+    my $creation = $format->parse_datetime( $fact->creation_time );
+
     return $self->create({
         id => $fact->guid,
-        created => $fact->creation_time,
+        created => $creation,
         report => \%report,
     });
 }
@@ -91,7 +94,7 @@ CPAN::Testers::Schema::ResultSet::TestReport - Query the raw test reports
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
